@@ -202,7 +202,7 @@ runcheck ./run testdata.in program.out \
 
 # Check for still running processes:
 if ps -u "$RUNUSER" >/dev/null 2>&1 ; then
-	error "found processes still running"
+	error "found processes still running as '$RUNUSER', check manually"
 fi
 
 # Append (heading/trailing) program stderr to error.tmp:
