@@ -11,8 +11,11 @@ require(LIBWWWDIR . '/checkers.jury.php');
 $times = array ('activate','start','freeze','end','unfreeze');
 $now = now();
 
-if ( IS_ADMIN && isset($_POST['donow']) ) {
-	$time = array_pop(array_keys($_POST['donow']));
+if ( isset($_POST['donow']) ) {
+
+	requireAdmin();
+
+	$time = key($_POST['donow']);
 	if ( !in_array($time, $times) ) error("Unknown value for timetype");
 	// for activatetime  we don't have a current contest to use,
 	// so we need to get it from the form data.
@@ -51,7 +54,7 @@ if ( isset($_GET['edited']) ) {
             msgbox (
                 "Warning: Refresh scoreboard cache",
 		"After changing the contest start time, it may be necessary to recalculate any cached scoreboards.<br /><br />" .
-		addSubmit('recalculate caches now', 'refresh') 
+		addSubmit('recalculate caches now', 'refresh')
 		) .
 		addEndForm();
 
@@ -75,9 +78,8 @@ if ( empty($cid) )  {
 		     "</em>; active from " . $row['activatetime'] .
 		     "<br /><br />\n";
 		if ( IS_ADMIN ) echo "<input type=\"submit\" " .
-		     "name=\"donow[activate][" . (int)$row['cid'] . 
+		     "name=\"donow[activate][" . (int)$row['cid'] .
 		     "]\" value=\"activate now\" />\n";
-		
 	} else {
 		echo "<p class=\"nodata\">No upcoming contest</p>\n";
 	}
@@ -118,7 +120,7 @@ if ( empty($cid) )  {
 		if ( IS_ADMIN && (
 		 ( $time == 'start' && !$hasstarted ) ||
 		 ( $time == 'end' && $hasstarted && !$hasended && (empty($row['freezetime']) || $hasfrozen) ) ||
-		 ( $time == 'freeze' && $hasstarted && !$hasended && !$hasfrozen ) || 
+		 ( $time == 'freeze' && $hasstarted && !$hasended && !$hasfrozen ) ||
 		 ( $time == 'unfreeze' && $hasfrozen && !$hasunfrozen && $hasended ) ) ) {
 			echo addSubmit("$time now", "donow[$time]");
 		}
@@ -155,7 +157,7 @@ if( count($res) == 0 ) {
 			( $iseven ? 'roweven': 'rowodd' ) .
 			(!$row['enabled']    ? ' disabled' :'') .
 			($row['cid'] == $cid ? ' highlight':'') . '">' .
-			"<td align=\"right\">" . $link .
+			"<td class=\"tdright\">" . $link .
 			"c" . (int)$row['cid'] . "</a></td>\n";
 		foreach ($times as $time) {
 			echo "<td title=\"".htmlspecialchars(@$row[$time. 'time']) . "\">" .
